Automatic USB running
=====================

![CI workflow](https://github.com/sourcebots/runusb/actions/workflows/ci.yml/badge.svg)

Watches for mounted filesystems with `.autorun` files, and runs those files,
well, automatically.
